@@ -150,6 +150,46 @@ impl Sf144 {
     pub fn as_sf52(&self) -> Sf52 {
         Sf52::new(self.value as f32)
     }
+
+    /// Raises a number to a floating point power
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use seximal::Sf144;
+    ///
+    /// let x = Sf144::new(2.0);
+    /// let abs_difference = (x.powf(Sf144::new(2.0)) - x * x).abs();
+    ///
+    /// assert!(abs_difference.value() <= f64::EPSILON);
+    /// ```
+    pub fn powf(self, n: Self) -> Self {
+        Self {
+            value: self.value.powf(n.value),
+        }
+    }
+
+    /// Computes the absolute value of `self`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use seximal::Sf144;
+    ///
+    /// let x = Sf144::new(3.5);
+    /// let y = Sf144::new(-3.5);
+    ///
+    /// let abs_difference_x = (x.abs() - x).abs();
+    /// let abs_difference_y = (y.abs() + y).abs();
+    ///
+    /// assert!(abs_difference_x.value() <= f64::EPSILON);
+    /// assert!(abs_difference_y.value() <= f64::EPSILON);
+    /// ```
+    pub fn abs(self) -> Self {
+        Self {
+            value: self.value.abs(),
+        }
+    }
 }
 
 impl fmt::Display for Sf144 {
